@@ -1,40 +1,42 @@
-test_that("IOV is added to parameters", {
-  skip_on_cran()
-  set.seed(32)
-  pars <- list(
-    "kappa_CL_1" = 0,
-    "kappa_CL_2" = 0,
-    "kappa_CL_3" = 0,
-    "kappa_CL_4" = 0,
-    "eta_CL" = 0,
-    "CL" = 5,
-    "V" = 50,
-    "KA" = 1
-  )
-  pk1 <- new_ode_model(
-    code = "
+pars <- list(
+  "kappa_CL_1" = 0,
+  "kappa_CL_2" = 0,
+  "kappa_CL_3" = 0,
+  "kappa_CL_4" = 0,
+  "eta_CL" = 0,
+  "CL" = 5,
+  "V" = 50,
+  "KA" = 1
+)
+pk1 <- new_ode_model(
+  code = "
       CL_iov = CL * exp(kappa_CL + eta_CL);
       dAdt[1] = -KA * A[1]
       dAdt[2] = +KA * A[1] -(CL_iov/V) * A[2]
     ",
-    iov = list(
-      cv = list(CL = 0.2),
-      n_bins = 4
-    ),
-    obs = list(cmt = 2, scale = "V"),
-    dose = list(cmt = 1, bioav = 1),
-    declare_variables = c("kappa_CL", "CL_iov"),
-    parameters = names(pars),
-    cpp_show_code = F
-  )
+  iov = list(
+    cv = list(CL = 0.2),
+    n_bins = 4
+  ),
+  obs = list(cmt = 2, scale = "V"),
+  dose = list(cmt = 1, bioav = 1),
+  declare_variables = c("kappa_CL", "CL_iov"),
+  parameters = names(pars),
+  cpp_show_code = F
+)
+
+reg1 <- new_regimen(
+  amt = 100,
+  interval = 24,
+  n = 5,
+  type = "infusion"
+)
+iov_var <- 0.3 ^ 2 # 30% IOV
+
+test_that("IOV is added to parameters", {
+  skip_on_cran()
+  set.seed(32)
 
-  reg1 <- new_regimen(
-    amt = 100,
-    interval = 24,
-    n = 5,
-    type = "infusion"
-  )
-  iov_var <- 0.3 ^ 2 # 30% IOV
   dat <- sim(
     ode = pk1,
     parameters = pars,
@@ -130,3 +132,54 @@ test_that("Change in F in 2nd bin is applied in 2nd bin and not later.", {
   res2 <- do.call("sim_ode", args = args_sim2)
   expect_true(min(res1[res1$y != res2$y,]$t) <= 25)
 })
+
+test_that("error is not invoked when using parameters_table", {
+  parameters_table <- data.frame(
+    CL = runif(10), V = runif(10), KA = runif(10), eta_CL = runif(10),
+    kappa_CL_1 = 0, kappa_CL_2 = 0, kappa_CL_3 = 0, kappa_CL_4 = 0
+  )
+
+  # specifying both parameters_table but for a model with IOV should not fail!
+  expect_silent(
+    dat <- sim(
+      ode = pk1,
+      parameters_table = parameters_table,
+      regimen = reg1,
+      omega = c(
+        iov_var, # IOV in CL
+        0, iov_var,
+        0, 0, iov_var,
+        0, 0, 0, iov_var,
+        0, 0, 0, 0, 0.3 # IIV in CL
+      ),
+      n = 5,
+      iov_bins = c(0, 24, 48, 72),
+      omega_type = "normal",
+      only_obs = TRUE,
+      output_include = list(parameters = TRUE, variables = TRUE)
+    )
+  )
+
+  # specifying both parameters and parameters_table should fail
+  expect_error(
+    dat <- sim(
+      ode = pk1,
+      parameters = pars,
+      parameters_table = parameters_table,
+      regimen = reg1,
+      omega = c(
+        iov_var, # IOV in CL
+        0, iov_var,
+        0, 0, iov_var,
+        0, 0, 0, iov_var,
+        0, 0, 0, 0, 0.3 # IIV in CL
+      ),
+      n = 5,
+      iov_bins = c(0, 24, 48, 72),
+      omega_type = "normal",
+      only_obs = TRUE,
+      output_include = list(parameters = TRUE, variables = TRUE)
+    )
+  )
+
+})
